function create2figures(X1, YMatrix1, X2, YMatrix2)
%CREATEFIGURE(X1, YMatrix1, X2, YMatrix2)
%  X1:  vector of x data
%  YMATRIX1:  matrix of y data
%  X2:  vector of x data
%  YMATRIX2:  matrix of y data

%  Auto-generated by MATLAB on 09-Apr-2019 21:32:48

% Create figure
figure1 = figure('WindowState','maximized');

% Create axes
axes1 = axes('Parent',figure1);
hold(axes1,'on');

% Create multiple lines using matrix input to plot
plot1 = plot(X1,YMatrix1,'Marker','x','LineWidth',15,'LineStyle','none');
set(plot1(1),'DisplayName','Tokuda, unikatowe',...
    'Color',[0 0.450980392156863 0.741176470588235]);
set(plot1(2),'DisplayName','Tokuda, nieunikatowe',...
    'Color',[0.850980392156863 0.329411764705882 0.101960784313725]);

% Create multiple lines using matrix input to plot
plot2 = plot(X2,YMatrix2,'DisplayName','Interpolacja funkcj? wyk?adnicz?',...
    'LineWidth',6);
set(plot2(1),'Color',[0 0.450980392156863 0.741176470588235]);
set(plot2(2),...
    'Color',[0.850980392156863 0.329411764705882 0.101960784313725]);

% Create ylabel
ylabel({'Czas wykonywania [s]'});

% Create xlabel
xlabel({'Liczebno?? zbioru'});

% Create title
title('Zale?no?? czasu wykonania algorytmu od liczebno?ci zbioru sortowanego');

box(axes1,'on');
% Set the remaining axes properties
set(axes1,'FontSize',20,'XGrid','on','YGrid','on');
% Create legend
legend1 = legend(axes1,'show');
set(legend1,...
    'Position',[0.140277783101838 0.782485879390648 0.205208328009272 0.129112658329524]);

